==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-sysstat/translations/sysstat_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Цвета статистических данных системы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>График</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Сетка</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Изменить…</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>&amp;Название</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>ЦПУ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Приоритет</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>&amp;Прочее</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Частота</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>&amp;Система</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Пользователь</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation>&amp;Кэшировано</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>&amp;Подкачка</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Приложения</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Буферы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Получено</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Передано</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation>Настройки статистических данных системы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>График</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation>&amp;Минимальный размер</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation>И&amp;нтервал обновления</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>&amp;Название</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation>&amp;Линий сетки</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation> с</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation>Данные</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation>Использовать &amp;частоту</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation>Ма&amp;ксимум</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation>XXX Кб</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation>Ло&amp;гарифмическая шкала</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation> шаги</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>ЦПУ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>Память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation>ЦП</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation>ЦП0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation>ЦП1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation>ЦП2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation>ЦП3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation>ЦП4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation>ЦП5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation>ЦП6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation>ЦП7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation>ЦП8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation>ЦП9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation>ЦП10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>ЦП11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>ЦП12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>ЦП13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>ЦП14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>ЦП15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>ЦП16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>ЦП17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>ЦП18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>ЦП19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>ЦП20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>ЦП21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>ЦП22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>ЦП23</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>файл подкачки</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>&amp;Источник</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>&amp;Тип</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colours</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation>Использовать цвета &amp;темы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation>Использовать с&amp;вои цвета</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>Свои цвета…</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="397"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation>система: %1%&lt;br&gt;пользователь: %2%&lt;br&gt;nice: %3%&lt;br&gt;прочее: %4%&lt;br&gt;частота: %5%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="446"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation>система: %1%&lt;br&gt;пользователь: %2%&lt;br&gt;nice: %3%&lt;br&gt;прочее: %4%&lt;br&gt;частота: n/a</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="488"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation>приложения: %1%&lt;br&gt;буферы: %2%&lt;br&gt;кэшировано: %3%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="522"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation>использовано: %1%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="552"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>мин.: %1%&lt;br&gt;макс.: %2%</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-sysstat/translations/sysstat_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Цвета статистических данных системы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>График</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Сетка</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Изменить…</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>&amp;Название</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>ЦПУ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Приоритет</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>&amp;Прочее</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Частота</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>&amp;Система</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Пользователь</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation>&amp;Кэшировано</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>&amp;Подкачка</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Приложения</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Буферы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Получено</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Передано</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation>Настройки статистических данных системы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>График</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation>&amp;Минимальный размер</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation>И&amp;нтервал обновления</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>&amp;Название</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation>&amp;Линий сетки</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Минимальная ширина панели, если она горизинтальная.&lt;/p&gt;&lt;p&gt;Минимальная высота — если вертикальная.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation> с</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation>Данные</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation>Использовать &amp;частоту</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation>Ма&amp;ксимум</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation>XXX Кб</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation>Ло&amp;гарифмическая шкала</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation> шаги</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>ЦПУ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>Память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation>ЦП</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation>ЦП0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation>ЦП1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation>ЦП2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation>ЦП3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation>ЦП4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation>ЦП5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation>ЦП6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation>ЦП7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation>ЦП8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation>ЦП9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation>ЦП10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>ЦП11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>ЦП12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>ЦП13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>ЦП14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>ЦП15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>ЦП16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>ЦП17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>ЦП18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>ЦП19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>ЦП20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>ЦП21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>ЦП22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>ЦП23</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>память</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>файл подкачки</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>&amp;Источник</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>&amp;Тип</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colours</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation>Использовать цвета &amp;темы</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation>Использовать с&amp;вои цвета</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>Свои цвета…</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="392"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation>система: %1%&lt;br&gt;пользователь: %2%&lt;br&gt;nice: %3%&lt;br&gt;прочее: %4%&lt;br&gt;частота: %5%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="441"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation>система: %1%&lt;br&gt;пользователь: %2%&lt;br&gt;nice: %3%&lt;br&gt;прочее: %4%&lt;br&gt;частота: n/a</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="483"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation>приложения: %1%&lt;br&gt;буферы: %2%&lt;br&gt;кэшировано: %3%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="517"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation>использовано: %1%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="547"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>мин.: %1%&lt;br&gt;макс.: %2%</translation>
    </message>
</context>
</TS>
